@@ -7,7 +7,23 @@
 #   $TEST_HOME	This folder
 
 
-# We must be called from tests/ !!
+# Unset config vars
+unset PASSWORD_STORE_DIR
+unset PASSWORD_STORE_KEY
+unset PASSWORD_STORE_GIT
+unset PASSWORD_STORE_GPG_OPTS
+unset PASSWORD_STORE_X_SELECTION
+unset PASSWORD_STORE_CLIP_TIME
+unset PASSWORD_STORE_UMASK
+unset PASSWORD_STORE_GENERATED_LENGTH
+unset PASSWORD_STORE_CHARACTER_SET
+unset PASSWORD_STORE_CHARACTER_SET_NO_SYMBOLS
+unset PASSWORD_STORE_ENABLE_EXTENSIONS
+unset PASSWORD_STORE_EXTENSIONS_DIR
+unset PASSWORD_STORE_SIGNING_KEY
+unset EDITOR
+
+# We must be called from tests/
 TEST_HOME="$(pwd)"
 
 . ./sharness.sh
