@@ -8,7 +8,8 @@ test_expect_success 'Test "edit" command' '
 	"$PASS" init $KEY1 &&
 	"$PASS" generate cred1 90 &&
 	export FAKE_EDITOR_PASSWORD="big fat fake password" &&
-	export EDITOR="$TEST_HOME/fake-editor-change-password.sh" &&
+	export PATH="$TEST_HOME:$PATH"
+	export EDITOR="fake-editor-change-password.sh" &&
 	"$PASS" edit cred1 &&
 	[[ $("$PASS" show cred1) == "$FAKE_EDITOR_PASSWORD" ]]
 '
